import React, { useRef, useState } from 'react'
import List from '@/components/Page/List'
import { Button, Tag, Image } from 'antd'
import { useNavigate } from 'react-router-dom'

export default (props) => {
  const navigate = useNavigate();

  const columns = [
    {
      title: '标题',
      dataIndex: 'title',
      ellipsis: true,
    },
    {
      title: '描述',
      dataIndex: 'describe',
      ellipsis: true,
      search: false,
    },
    {
      title: '正文',
      dataIndex: 'content',
      ellipsis: { showTitle: false },
      search: false,
    },
    {
      title: '标签',
      dataIndex: 'tag',
      search: false,
      render: (_, it) => <Tag color="red">{it?.tag}</Tag>
    },
    {
      title: '横向封面图',
      dataIndex: 'HImg',
      render: (_, it) => <Image src={it?.HImg} width={80} />,
      search: false,
    },
    {
      title: '纵向封面图',
      dataIndex: 'VImg',
      render: (_, it) => <Image src={it?.VImg} width={80} />,
      search: false,
    },
    {
      title: '图片',
      dataIndex: 'img',
      render: (_, it) => <Image src={it?.img} width={80} />,
      search: false,
    },
    {
      title: '分类',
      dataIndex: 'classify'
    },
    {
      title: '链接地址',
      dataIndex: 'link',
      ellipsis: true,
      render: (_, it) => <a href="#">{it?.link}</a>,
      search: false,
    },
    {
      title: '附件',
      dataIndex: 'attachment',
      search: false,
    }
  ]

  const dataSource = [
    {
      id: 1,
      title: 'AIgc',
      describe: '我喜欢的智能',
      content: 'AIGC，全称为AI-Generated Content，是指基于人工智能技术自动生成各种类型的内容，如文本、图像、声音、视频等。它利用已有数据寻找规律，并自动生成内容，既是一种内容分类方式，也是一种内容生产方式，还是一种用于内容自动生成的一类技术集合。AIGC涵盖了人工智能、计算机图形学和深度学习等领域技术的综合平台，其目的在于将这些技术结合起来，实现更加高效、智能化的图像识别和处理，提升人机交互的用户体验。与百度AI文心一言和ChatGPT相比，AIGC主要侧重于图像识别与处理等技术，而百度AI文心一言则更侧重于自然语言处理。AIGC在多个领域具有广泛的应用。在智能安防领域，它可以通过图像识别技术实现人脸识别、车辆识别等功能，提升安全监控的效率和准确性。在游戏和虚拟现实领域，AIGC可以实现高度逼真的图像渲染和物理模拟，提升游戏体验。此外，AIGC还可以参与内容共创，推动媒体融合转型，参与制作全流程，推进虚实交融，提供发展动能，助力产业加快升级等。具体来说，AIGC可以生成高质量、独特的图像作品，包括绘画、插图、设计、艺术品等；可以创作音乐、歌曲、声音效果或其他音频内容，提供新颖和多样化的音乐体验；可以生成影片、动画、短视频等，具备专业级的画面效果和剧情呈现；还可以生成3D模型、场景、动画等，为游戏开发、虚拟现实和影视制作提供多样化的创意和设计。然而，尽管AIGC具有强大的创造力，但仍然需要人类的指导和监督，以确保创作的质量和道德性。在创作过程中，AIGC会遵循人类设定的规则和算法，但其结果仍然需要人类进行审查和评估，以确保内容符合社会价值观和法律法规。总的来说，AIGC是一种强大的内容生成工具，其应用前景广阔，将在未来为人们的生活带来更多便利和乐趣。',
      tag: 'ai',
      HImg: 'https://gw.alipayobjects.com/zos/antfincdn/cV16ZqzMjW/photo-1473091540282-9b846e7965e3.webp',
      VImg: 'https://gw.alipayobjects.com/zos/antfincdn/LlvErxo8H9/photo-1503185912284-5271ff81b9a8.webp',
      img: 'https://gw.alipayobjects.com/zos/antfincdn/aPkFc8Sj7n/method-draw-image.svg',
      classify: '人工智能',
      link: 'https://www.baidu.com/',
    }
  ]

  const onEdit = (_, it) => {
    navigate(`/article/edit?id=${'it.id'}`)
  }

  return (
    <List
      rowKey="id"
      columns={columns}
      dataSource={dataSource}
      onEdit={onEdit}
      request={{}}
      toolBarRender={() => [
        <Button
          key="2"
          type="primary"
          onClick={() => {
            navigate('/article/edit')
          }}
        >
          新增
        </Button>
      ]}
      columnOptionRender={() => [
        <Button
          key="3"
          type="link"
          onClick={() => {
            navigate('/article/detail')
          }}
        >
          详情
        </Button>,
      ]}
    />
  )
}